==> MMDX-v1.20a-src.zip: MMDX-v1.20a-src/MMDImporter/Model/SkinnedModelProcessor.cs <==
using System.IO;
using Microsoft.Xna.Framework.Content.Pipeline;
using Microsoft.Xna.Framework.Content.Pipeline.Graphics;
using Microsoft.Xna.Framework.Content.Pipeline.Processors;
using System.ComponentModel;
using Microsoft.Xna.Framework.Content;


namespace MikuMikuDance.XNA.Model
{
    /// <summary>
    /// /// RegEpCvC̒ԃf[^łNodeContent
    /// Aj[Vf[^܂ModelContent֕ϊvZbT
    /// </summary>
    [ContentProcessor]
    internal class SkinnedModelProcessor : ModelProcessor
    {
        [DefaultValue("")]
        public string EffectFile { get; set; }

        /// <summary>
        /// RegEpCvC̒ԃf[^łNodeContent
        /// Aj[Vf[^܂ModelContent֕ϊProcess\bhB
        /// CMMDProcessorɔCāAł̓GtFNg̃vZXs
        /// </summary>
        public override ModelContent Process(NodeContent input, ContentProcessorContext context)
        {
            // x[XNXProcess\bhĂяoăff[^ϊ
            return base.Process(input, context);
        }

        /// <summary>
        /// SẴ}eAXLfp̃GtFNgg悤ɕύX
        /// </summary>
        protected override MaterialContent ConvertMaterial(MaterialContent material,
                                                        ContentProcessorContext context)
        {
            BasicMaterialContent basicMaterial = material as BasicMaterialContent;
            EffectMaterialContent effectMaterial;
            // XLbVGtFNgQƂ
            
            ExternalReference<EffectContent> effect;
            if (EffectFile == "")
            {
                //\[Xt@C쐬ēǂݍނƂZRC@cc
                if (!Directory.Exists("ext"))
                    Directory.CreateDirectory("ext");
                FileStream fs = new FileStream(Path.Combine("ext", "MMDModel.fx"), FileMode.Create);
                BinaryWriter bw = new BinaryWriter(fs);
                bw.Write(Resource1.MMDModel);
                bw.Close();
                effect = new ExternalReference<EffectContent>(Path.Combine("ext", "MMDModel.fx"));
                //effect = new ExternalReference<EffectContent>("MMDModel.fx");
            }
            else
                effect = new ExternalReference<EffectContent>(Path.GetFullPath(EffectFile));
            
            if (basicMaterial == null)
            {
                effectMaterial = material as EffectMaterialContent;
                if (effectMaterial == null)
                    throw new InvalidContentException(string.Format(
                    "MMDProcessorEffectMaterialContent܂BasicMaterialContent݂̂T|[g܂" +
                    "̓bV{0}gpĂ܂B", material.GetType()));
                // XLbVGtFNg𖄂ߍ
                effectMaterial.Effect = effect;
                ResizeTexturesToPowerOfTwo = true;
                //@ModelProcessorConvertMaterialĂ
                return base.ConvertMaterial(effectMaterial, context);
            }
            else
            {

                effectMaterial = new EffectMaterialContent();

                // XLbVGtFNg𖄂ߍ
                effectMaterial.Effect = effect;
                
                // BasicMaterialContent̃eNX`V}eAɐݒ肷
                if (basicMaterial.Texture != null)
                    effectMaterial.Textures.Add("Texture", basicMaterial.Texture);
                ResizeTexturesToPowerOfTwo = true;
                
                //@ModelProcessorConvertMaterialĂ
                return base.ConvertMaterial(effectMaterial, context);
            }
        }
    }
}

==> MMDX-v1.41a-src.zip: MMDX-v1.41a-src/MMDImporter/Model/SkinnedModelProcessor.cs <==
using System.IO;
using Microsoft.Xna.Framework.Content.Pipeline;
using Microsoft.Xna.Framework.Content.Pipeline.Graphics;
using Microsoft.Xna.Framework.Content.Pipeline.Processors;
using System.ComponentModel;
using Microsoft.Xna.Framework.Content;


namespace MikuMikuDance.XNA.Model
{
    /// <summary>
    /// /// RegEpCvC̒ԃf[^łNodeContent
    /// Aj[Vf[^܂ModelContent֕ϊvZbT
    /// </summary>
    [ContentProcessor]
    internal class SkinnedModelProcessor : ModelProcessor
    {
        [DefaultValue("")]
        public string EffectFile { get; set; }

        /// <summary>
        /// RegEpCvC̒ԃf[^łNodeContent
        /// Aj[Vf[^܂ModelContent֕ϊProcess\bhB
        /// CMMDProcessorɔCāAł̓GtFNg̃vZXs
        /// </summary>
        public override ModelContent Process(NodeContent input, ContentProcessorContext context)
        {
            // x[XNXProcess\bhĂяoăff[^ϊ
            return base.Process(input, context);
        }

        /// <summary>
        /// SẴ}eAXLfp̃GtFNgg悤ɕύX
        /// </summary>
        protected override MaterialContent ConvertMaterial(MaterialContent material,
                                                        ContentProcessorContext context)
        {
            BasicMaterialContent basicMaterial = material as BasicMaterialContent;
            EffectMaterialContent effectMaterial;
            // XLbVGtFNgQƂ
            
            ExternalReference<EffectContent> effect;
            if (EffectFile == "")
            {
                //\[Xt@C쐬ēǂݍނƂZRC@cc
                if (!Directory.Exists("ext"))
                    Directory.CreateDirectory("ext");
                FileStream fs = new FileStream(Path.Combine("ext", "MMDModel.fx"), FileMode.Create);
                BinaryWriter bw = new BinaryWriter(fs);
                bw.Write(Resource1.MMDModel);
                bw.Close();
                effect = new ExternalReference<EffectContent>(Path.Combine("ext", "MMDModel.fx"));
            }
            else
                effect = new ExternalReference<EffectContent>(Path.GetFullPath(EffectFile));
            
            if (basicMaterial == null)
            {
                effectMaterial = material as EffectMaterialContent;
                if (effectMaterial == null)
                    throw new InvalidContentException(string.Format(
                    "MMDProcessorEffectMaterialContent݂̂T|[g܂" +
                    "̓bV{0}gpĂ܂B", material.GetType()));
                // XLbVGtFNg𖄂ߍ
                effectMaterial.Effect = effect;
                //@ModelProcessorConvertMaterialĂ
                return base.ConvertMaterial(effectMaterial, context);
            }
            else
            {
                //ImporterEffectMaterialgĂȏAɗ͂̂cc
                throw new InvalidContentException(string.Format(
                    "MMDProcessorEffectMaterialContent݂̂T|[g܂" +
                    "̓bV{0}gpĂ܂B", material.GetType()));
                /*
                effectMaterial = new EffectMaterialContent();

                // XLbVGtFNg𖄂ߍ
                effectMaterial.Effect = effect;
                
                // BasicMaterialContent̃eNX`V}eAɐݒ肷
                if (basicMaterial.Texture != null)
                    effectMaterial.Textures.Add("Texture", basicMaterial.Texture);
                
                //@ModelProcessorConvertMaterialĂ
                return base.ConvertMaterial(effectMaterial, context);*/
            }
        }
    }
}
